wordcount_file
==============
This project came out of an exercise to the number of words in a text file and display the top results.


Installation
------------
Run this to install
::

    pip install wordcount_file


Usage
-----
Create a WordCount object:
::

    >> import wordcount_file
    >> wc = wordcount_file.WordCount('file_to_count.txt')

